@@ -2,7 +2,7 @@
 #define POLYNOMIAL_H
 
 #include "Cpp14MakeUnique.h"
-#include "SieveUtils.h"
+#include "MultPoly.h"
 #include "StatsUtils.h"
 
 using typeTimePoint = std::chrono::time_point<std::chrono::steady_clock>;
@@ -38,11 +38,13 @@ private:
     void SetMpzFacSize(int _mpzFacSize) {mpzFacSize = _mpzFacSize;}
     
     void SievePolys(const std::vector<std::size_t> &SieveDist,
-                    const std::vector<int> &facBase, const std::vector<int> &LnFB, 
+                    const std::vector<int> &facBase,
+                    const std::vector<logType> &LnFB,
                     const std::vector<mpz_class> &mpzFacBase,
-                    const mpz_class &LowBound, const mpz_class &myNum,
-                    int theCut, int DoubleLenB, int vecMaxSize,
-                    std::size_t strt, std::size_t polyLimit);
+                    const mpz_class &myNum, int LowBound,
+                    logType theCut, int TwiceLenB, int vecMaxSize,
+                    std::size_t strt, std::size_t vecMaxStrt,
+                    std::size_t polyLimit);
     
 public:
     
@@ -50,25 +52,32 @@ public:
     Polynomial(std::size_t _facSize, bool _bShowStats, const mpz_class &myNum);
     
     void InitialParSieve(const std::vector<std::size_t> &SieveDist,
-                         const std::vector<int> &facBase, const std::vector<int> &LnFB,
-                         std::vector<mpz_class> &mpzFacBase, mpz_class &NextPrime,
-                         const mpz_class &LowBound, const mpz_class &myNum, int theCut,
-                         int DoubleLenB, int vecMaxSize, std::size_t strt,
-                         typeTimePoint checkPoint0);
+                         const std::vector<int> &facBase,
+                         const std::vector<logType> &LnFB,
+                         std::vector<mpz_class> &mpzFacBase,
+                         mpz_class &NextPrime, const mpz_class &myNum,
+                         int LowBound, logType theCut, int TwiceLenB,
+                         int vecMaxSize, std::size_t strt,
+                         std::size_t vecMaxStrt, typeTimePoint checkPoint0);
     
     void FactorParallel(const std::vector<std::size_t> &SieveDist,
-                        const std::vector<int> &facBase, const std::vector<int> &LnFB,
-                        std::vector<mpz_class> &mpzFacBase, mpz_class &NextPrime,
-                        const mpz_class &LowBound, const mpz_class &myNum, int theCut,
-                        int DoubleLenB, int vecMaxSize, std::size_t strt,
-                        typeTimePoint checkPoint0, std::size_t nThreads);
+                        const std::vector<int> &facBase, 
+                        const std::vector<logType> &LnFB,
+                        std::vector<mpz_class> &mpzFacBase,
+                        mpz_class &NextPrime, const mpz_class &myNum,
+                        int LowBound, logType theCut, int TwiceLenB,
+                        int vecMaxSize, std::size_t strt,
+                        std::size_t vecMaxStrt, typeTimePoint checkPoint0,
+                        std::size_t nThreads);
     
     void FactorSerial(const std::vector<std::size_t> &SieveDist,
-                      const std::vector<int> &facBase, const std::vector<int> &LnFB,
-                      std::vector<mpz_class> &mpzFacBase, mpz_class &NextPrime,
-                      const mpz_class &LowBound, const mpz_class &myNum, int theCut,
-                      int DoubleLenB, int vecMaxSize, std::size_t strt,
-                      typeTimePoint checkPoint0);
+                      const std::vector<int> &facBase,
+                      const std::vector<logType> &LnFB,
+                      std::vector<mpz_class> &mpzFacBase,
+                      mpz_class &NextPrime, const mpz_class &myNum,
+                      int LowBound, logType theCut, int TwiceLenB,
+                      int vecMaxSize, std::size_t strt,
+                      std::size_t vecMaxStrt, typeTimePoint checkPoint0);
     
     void GetSolution(const std::vector<mpz_class> &mpzFacBase, 
                      const std::vector<int> &facBase, std::vector<mpz_class> &factors,
